@@ -265,7 +265,7 @@ pub async fn process<C: Context + Send>(
             match payment.state {
                 PaymentState::Succeeded => {
                     internal_ctx
-                        .payment_processing_topic
+                        .checkout_completion_topic
                         .clone()
                         .publish(&payment.checkout_id)
                         .await
